from .Base import Base


class Issuer(Base):
    pass
